-- Tabulka časové řady
CREATE TABLE USRBUF.TSP_MEC_CONS_RE
(	
    OID NUMBER(22,0) NOT NULL, 
    OID_MGA NUMBER(22,0) NOT NULL, 
    OID_RE NUMBER(22,0) NOT NULL, 
    OID_CONSUMPTION_TYPE NUMBER(22,0) NOT NULL, 
    OID_MEASUREMENT_TYPE NUMBER(22,0) NOT NULL, 
    FROM_TIME TIMESTAMP(6) NOT NULL, 
    TO_TIME TIMESTAMP(6) NOT NULL, 
    VAL_MEC_ID NVARCHAR2(100), 
    VAL_S_MEC_ID CHAR(1 BYTE) DEFAULT 'P' NOT NULL
)
COMPRESS NOLOGGING
TABLESPACE N_DAE_DATA;

-- B-tree index primárního klíče a integritní omezení
CREATE UNIQUE INDEX USRBUF.PK_TSP_MEC_CONS_RE 
ON USRBUF.TSP_MEC_CONS_RE (OID) 
TABLESPACE N_DAE_INDX
NOLOGGING;

ALTER TABLE USRBUF.TSP_MEC_CONS_RE 
ADD CONSTRAINT PK_TSP_MEC_CONS_RE 
PRIMARY KEY (OID)
USING INDEX USRBUF.PK_TSP_MEC_CONS_RE;

-- B-tree index unikátní kombinace klíče a integritní omezení
CREATE UNIQUE INDEX USRBUF.UQ_TSP_MEC_CONS_RE 
ON USRBUF.TSP_MEC_CONS_RE (TO_TIME, FROM_TIME, OID_RE, OID_MGA, OID_CONSUMPTION_TYPE, OID_MEASUREMENT_TYPE) 
TABLESPACE N_DAE_INDX
NOLOGGING;

ALTER TABLE USRBUF.TSP_MEC_CONS_RE 
ADD CONSTRAINT UQ_TSP_MEC_CONS_RE 
UNIQUE (TO_TIME, FROM_TIME, OID_RE, OID_MGA, OID_CONSUMPTION_TYPE, OID_MEASUREMENT_TYPE)
USING INDEX USRBUF.UQ_TSP_MEC_CONS_RE;

-- Pohled
CREATE OR REPLACE VIEW USRBUF.N_AF_MEC_CONS_RE AS 
SELECT 
    OID, 
    FROM_TIME, 
    TO_TIME,
    OID_MGA AS MGA,
    OID_RE AS RE,
    OID_CONSUMPTION_TYPE AS CONSUMPTION_TYPE,
    OID_MEASUREMENT_TYPE AS MEASUREMENT_TYPE, 
    VAL_MEC_ID AS MEC_ID,
    VAL_S_MEC_ID AS MEC_ID_I
FROM TSP_MEC_CONS_RE
WHERE VAL_S_MEC_ID != 'D';

COMMIT;