-- Vytvoření tabulky T101TIME_UNIT
CREATE TABLE USRBUF.T101TIME_UNIT 
(
    OID NUMBER(22,0) NOT NULL, 
    T101NAME NVARCHAR2(2000) NOT NULL, 
    T101CODE VARCHAR2(255 BYTE) NOT NULL, 
    T101DESCRIPTION NVARCHAR2(2000)
)
NOCOMPRESS
TABLESPACE O_DAE_DATA;

-- B-tree index primárního klíče a integritní omezení
CREATE UNIQUE INDEX USRBUF.PK_T101TIMEUNIT 
ON USRBUF.T101TIME_UNIT (OID) 
TABLESPACE O_DAE_DATA;

ALTER TABLE USRBUF.T101TIME_UNIT 
ADD CONSTRAINT PK_T101TIMEUNIT 
PRIMARY KEY (OID)
USING INDEX USRBUF.PK_T101TIMEUNIT;

-- B-tree index unikátní kombinace klíče a integritní omezení
CREATE UNIQUE INDEX USRBUF.UQ_T101_T101CODE 
ON USRBUF.T101TIME_UNIT (T101CODE) 
TABLESPACE O_DAE_DATA;

ALTER TABLE USRBUF.T101TIME_UNIT 
ADD CONSTRAINT UQ_T101_T101CODE 
UNIQUE (T101CODE)
USING INDEX USRBUF.UQ_T101_T101CODE;

-- Vytvoření tabulky T103TIME_UNIT_VALUE
CREATE TABLE USRBUF.T103TIME_UNIT_VALUE
(
    OID NUMBER(22,0) NOT NULL, 
    T103FROM_DATE TIMESTAMP(6) NOT NULL, 
    T103TO_DATE TIMESTAMP(6) NOT NULL, 
    T101TIME_UNIT NUMBER(22,0) NOT NULL, 
    CONSTRAINT FK_T103TIME_UNIT_T101TIME_UNIT 
    FOREIGN KEY (T101TIME_UNIT)
    REFERENCES USRBUF.T101TIME_UNIT (OID)
) 
NOCOMPRESS
TABLESPACE O_DAE_DATA;

-- B-tree index primárního klíče a integritní omezení
CREATE UNIQUE INDEX USRBUF.PK_T03TIME_UNIT_VALUE 
ON USRBUF.T103TIME_UNIT_VALUE (OID) 
TABLESPACE O_DAE_DATA;

ALTER TABLE USRBUF.T103TIME_UNIT_VALUE 
ADD CONSTRAINT PK_T03TIME_UNIT_VALUE 
PRIMARY KEY (OID)
USING INDEX USRBUF.PK_T03TIME_UNIT_VALUE;

CREATE INDEX USRBUF.IDX_T103INDEX_TU 
ON USRBUF.T103TIME_UNIT_VALUE (T101TIME_UNIT) 
TABLESPACE O_DAE_DATA;

CREATE INDEX USRBUF.IDX_T103TIME_UNIT_VALUE_TIME 
ON USRBUF.T103TIME_UNIT_VALUE (T101TIME_UNIT, T103TO_DATE) 
TABLESPACE O_DAE_DATA;

CREATE INDEX USRBUF.IDX2_T103TIME_UNIT_VALUE_TIME 
ON USRBUF.T103TIME_UNIT_VALUE (T101TIME_UNIT, T103FROM_DATE, T103TO_DATE) 
TABLESPACE O_DAE_DATA;

INSERT ALL
INTO USRBUF.T101TIME_UNIT (OID, T101NAME, T101CODE, T101DESCRIPTION) VALUES (1, 'Quarter hour', 'QUARTER_HOUR', 'A time interval of fifteen consecutive minutes.')
INTO USRBUF.T101TIME_UNIT (OID, T101NAME, T101CODE, T101DESCRIPTION) VALUES (2, 'Hour', 'HOUR', 'The basic time unit - hour.')
INTO USRBUF.T101TIME_UNIT (OID, T101NAME, T101CODE, T101DESCRIPTION) VALUES (3, 'Day', 'DAY', 'The basic time unit - day.')
INTO USRBUF.T101TIME_UNIT (OID, T101NAME, T101CODE, T101DESCRIPTION) VALUES (4, 'Calendar week', 'WEEK_C', 'A time interval of seven consecutive days starting with Monday and ending with Sunday.')
INTO USRBUF.T101TIME_UNIT (OID, T101NAME, T101CODE, T101DESCRIPTION) VALUES (5, 'Month', 'MONTH', 'A calendar month.')
INTO USRBUF.T101TIME_UNIT (OID, T101NAME, T101CODE, T101DESCRIPTION) VALUES (6, 'Quarter', 'QUARTER', 'A TIME INTERVAL consisting OF three consecutive months.')
INTO USRBUF.T101TIME_UNIT (OID, T101NAME, T101CODE, T101DESCRIPTION) VALUES (7, 'Year', 'YEAR', 'A calendar YEAR.')
INTO USRBUF.T101TIME_UNIT (OID, T101NAME, T101CODE, T101DESCRIPTION) VALUES (8, 'Dynamic', 'DYNAMIC', 'Instance data of dynamic time unit timeseries can be in different time granularities.')
SELECT 1 FROM DUAL;

COMMIT;