-- Nastavení cíle optimalizátoru na prvních 100 řádků (pro relaci)
ALTER SESSION SET OPTIMIZER_MODE = FIRST_ROWS_100;

-- Nastavení převodu všech literálů (globálně, vyžaduje admin práva)
ALTER SYSTEM SET CURSOR_SHARING = FORCE;

-- Manuální sběr statistik indexu se vzorkováním 10%
EXECUTE DBMS_STATS.GATHER_INDEX_STATS('IDX_DATUM', 10);

-- Hint pro použití přístupové cesty full table scan
SELECT /*+ FULL(KNIHA) */ NAZEV 
FROM KNIHA
WHERE DATUM_VYDANI >= TO_DATE('01-01-2021', 'DD-MM-YYYY');

-- Povolení paralelizace DML operací
ALTER SESSION ENABLE PARALLEL DML;
-- Vynucení paralelizace DML operací s úrovní 4
ALTER SESSION FORCE PARALLEL DML PARALLEL 4;

-- Dotaz na plán získání učebnic vydaných v prvním týdnu února 2021
EXPLAIN PLAN FOR
SELECT t1.NAZEV 
FROM KNIHA t1
JOIN KATEGORIE t2 ON t2.ID = t1.KATEGORIE_ID
WHERE t1.DATUM_VYDANI >= '01-02-2021'
  AND t1.DATUM_VYDANI <= '07-02-2021'
  AND t2.NAZEV = 'UCEBNICE';

SELECT * FROM TABLE(DBMS_XPLAN.DISPLAY); -- Výpis plánu z tabulky

-- Získaný plán (za účelem ušetření místa byly odebrány některé sloupce)
---------------------------------------------------------------------------------------------------
| Id | Operation                           | Name          | Rows  | Cost (%CPU) | Pstart | Pstop |
---------------------------------------------------------------------------------------------------
|  0 | SELECT STATEMENT                    |               |   158 |     3   (0) |        |       |
|  1 |  NESTED LOOPS                       |               |   158 |     3   (0) |        |       |
|  2 |   TABLE ACCESS BY INDEX ROWID       | KATEGORIE     |     1 |     1   (0) |        |       |
|* 3 |    INDEX UNIQUE SCAN                | IDX_KATEGORIE |     1 |     0   (0) |        |       |
|  4 |   PARTITION RANGE SINGLE            |               |   158 |     2   (0) |      2 |     2 |
|  5 |    TABLE ACCESS BY LOCAL INDEX ROWID| KNIHA         |   158 |     2   (0) |      2 |     2 |
|* 6 |     INDEX RANGE SCAN                | IDX_KNIHA     |     4 |     2   (0) |      2 |     2 |
---------------------------------------------------------------------------------------------------
3 - access("T2"."NAZEV"='UCEBNICE')
6 - access("T2"."ID"="T1"."KATEGORIE_ID"
          AND "T1"."DATUM_VYDANI">=TO_DATE('2021-02-01 00:00:00', 'syyyy-mm-dd hh24:mi:ss')
          AND "T1"."DATUM_VYDANI"<=TO_DATE('2021-02-07 00:00:00', 'syyyy-mm-dd hh24:mi:ss'))
    filter("T2"."ID"="T1"."KATEGORIE_ID")