-- Rozsahové rozdělení
CREATE TABLE KNIHA
(
  NAZEV VARCHAR2(200) PRIMARY KEY,
  DATUM_VYDANI DATE NOT NULL
)
PARTITION BY RANGE(DATUM_VYDANI)
(
  PARTITION KNIHY_2021_Q1 VALUES LESS THAN('01/04/2021'),
  PARTITION KNIHY_2021_Q2 VALUES LESS THAN('01/07/2021')
);

-- Přidání dalšího oddílu do již existující tabulky
ALTER TABLE KNIHA ADD PARTITION KNIHY_2021_Q3 VALUES LESS THAN('01/10/2021');



-- Hashové rozdělení
CREATE TABLE KNIHA
(
  NAZEV VARCHAR2(200) PRIMARY KEY,
  KATEGORIE VARCHAR2(30) NOT NULL
)
PARTITION BY HASH(KATEGORIE)
PARTITIONS 2;



-- Seznamové rozdělení
CREATE TABLE KNIHA
(
  NAZEV VARCHAR2(200) PRIMARY KEY,
  KATEGORIE VARCHAR2(30) NOT NULL
)
PARTITION BY LIST(KATEGORIE)
(
  PARTITION UCEBNICE VALUES('ZEMEPIS', 'CHEMIE', 'MATEMATIKA'),
  PARTITION KUCHARKY VALUES('ITALSKA_KUCHYNE', 'CESKA_KUCHYNE')
);



-- Kompozitní rozdělení
CREATE TABLE KNIHA
(
  NAZEV VARCHAR2(100) PRIMARY KEY,
  DATUM_VYDANI DATE NOT NULL,
  KATEGORIE VARCHAR2(20) NOT NULL
)
PARTITION BY RANGE(DATUM_VYDANI)
SUBPARTITION BY HASH(KATEGORIE)
SUBPARTITIONS 6
(
  PARTITION DATA_21_Q1 VALUES LESS THAN('01/04/2021'),
  PARTITION DATA_21_Q2 VALUES LESS THAN('01/07/2021')
);



-- Rozdělení indexů
-- Lokální index se specifikací oddílů
CREATE INDEX INDEX_DATUM_VYDANI ON KNIHA(DATUM_VYDANI) LOCAL
(
	PARTITION KNIHY_2021_Q1,
	PARTITION KNIHY_2021_Q2
);

-- Globální index s odlišným rozdělením oproti tabulce
CREATE INDEX INDEX_DATUM_VYDANI ON KNIHA(DATUM_VYDANI) GLOBAL 
PARTITION BY RANGE(DATUM_VYDANI)
(
  PARTITION KNIHY_2021_LEDEN VALUES LESS THAN('01/02/2021'),
  PARTITION KNIHY_2021_UNOR VALUES LESS THAN('01/03/2021'),
  PARTITION KNIHY_MAX VALUES LESS THAN(MAXVALUE)
);

DROP TABLE KNIHA;