-- 3.3.1	Haldově uspořádaná tabulka
CREATE TABLE KNIHA
(
  NAZEV VARCHAR2(200) PRIMARY KEY,
  DATUM_VYDANI DATE NOT NULL
)
-- Není nutné explicitně uvádět
ORGANIZATION HEAP;



-- 3.3.2	Indexově uspořádaná tabulka
CREATE TABLE KNIHA
(
  NAZEV VARCHAR2(200) NOT NULL,
  DATUM_VYDANI DATE NOT NULL,
  CONSTRAINT PK_KNIHA PRIMARY KEY (NAZEV, DATUM_VYDANI)
)
ORGANIZATION INDEX;



-- 3.3.3	Dočasná tabulka
-- Globální dočasná tabulka
CREATE GLOBAL TEMPORARY TABLE KNIHA 
( 
  NAZEV VARCHAR2(200) PRIMARY KEY,
  DATUM_VYDANI DATE NOT NULL
) 
ON COMMIT DELETE ROWS; -- Odstranění dat po konci transakce

-- Privátní dočasná tabulka
CREATE PRIVATE TEMPORARY TABLE KNIHA 
( 
  NAZEV VARCHAR2(200) PRIMARY KEY,
  DATUM_VYDANI DATE NOT NULL
)
ON COMMIT PRESERVE DEFINITION; -- Odstranění tabulky po konci relace



-- 3.3.4	Seskupená tabulka
-- Vytvoření clusteru a jeho indexu
CREATE CLUSTER KNIHA_AUTOR(AUTOR_ID NUMBER(8, 0));
CREATE INDEX INDEX_KNIHA_AUTOR ON CLUSTER KNIHA_AUTOR;

-- Vytvořeni první tabulky clusteru
CREATE TABLE AUTOR
(
  ID NUMBER(8, 0) PRIMARY KEY,
  JMENO VARCHAR(300) NOT NULL
) 
CLUSTER KNIHA_AUTOR(ID);

-- Vytvořeni druhé tabulky clusteru
CREATE TABLE KNIHA
(
  NAZEV VARCHAR2(200) PRIMARY KEY,
  AUTOR_ID NUMBER(8, 0) NOT NULL
) 
CLUSTER KNIHA_AUTOR(AUTOR_ID);



-- 3.4	Pohledy
CREATE VIEW KNIHY_OD_A AS
(
  SELECT NAZEV, DATUM_VYDANI
  FROM KNIHA
  WHERE UPPER(NAZEV) LIKE 'A%'
) 
WITH READ ONLY; -- Specifikace režimu pouze pro čtení



-- 3.4.1	Materializovaný pohled
CREATE MATERIALIZED VIEW KNIHY_OD_A
BUILD DEFERRED -- Prvotní naplnění pohledu na vyžádání
REFRESH COMPLETE -- Kompletní aktualizace
ON DEMAND -- Manuální aktualizace
ENABLE QUERY REWRITE -- Povolení přepsání dotazu
AS
SELECT NAZEV, DATUM_VYDANI
FROM KNIHA
WHERE UPPER(NAZEV) LIKE 'A%';

DBMS_MVIEW.REFRESH('KNIHY_OD_A'); -- Zavolání manuální aktualizace